@@ -41,6 +41,7 @@ from .file import (
     TrackedFolderRevision,
     CreateWorkingCopyFromRevision,
     CreateWorkingCopyAction,
+    CreateWorkingCopyFromFile,
     PublishFileAction,
 )
 from .runners import (
@@ -141,6 +142,8 @@ class Project(flow.Object):
             return CreateWorkingCopyFromRevision
         elif slot_name == 'libreflow.baseflow.file.CreateWorkingCopyAction':
             return CreateWorkingCopyAction
+        elif slot_name == 'libreflow.baseflow.file.CreateWorkingCopyFromFile':
+            return CreateWorkingCopyFromFile
         elif slot_name == 'libreflow.baseflow.file.PublishFileAction':
             return PublishFileAction
         elif slot_name == 'libreflow.baseflow.file.Revision':
