@@ -11,8 +11,11 @@ from libreflow.baseflow.file import (
     FileSystemMap                 as BaseFileSystemMap,
     CreateWorkingCopyAction       as BaseCreateWorkingCopyAction,
     CreateWorkingCopyFromRevision as BaseCreateWorkingCopyFromRevision,
+    CreateWorkingCopyFromFile     as BaseCreateWorkingCopyFromFile,
     PublishFileAction             as BasePublishFileAction,
     RevisionsWorkingCopiesChoiceValue,
+    FileRevisionWorkingCopyNameChoiceValue,
+    FileRefRevisionNameChoiceValue
 )
 from libreflow.utils.flow import get_contextual_dict
 
@@ -46,6 +49,31 @@ class RevisionsWorkingCopies(RevisionsWorkingCopiesChoiceValue):
     _files = flow.Parent(3)
     _shot = flow.Parent(6)
 
+    def choices(self):
+        user = self.root().project().get_user()
+        revisions = None
+
+        if user.preferences.create_working_copies.get() == True:
+            revisions = self._file.get_revision_names(sync_status='Available')
+            for revision in revisions:
+                if revision == user.name():
+                    revisions.remove(revision)
+        else:
+            revisions = self._file.get_revision_names(sync_status='Available', published_only=True)
+
+        if user.all_working_copy.get() == False:
+            head = self._file.get_head_revision().name()
+            last_revisions = []
+            for revision in revisions:
+                if self._file.get_revision(revision).is_working_copy():
+                    last_revisions.append(revision)
+                    continue
+                if revision == head:
+                    last_revisions.append(revision)
+            return last_revisions
+        
+        return revisions
+
     def _fill_ui(self, ui):
         ui['hidden'] = (
             self._shot.get_task_status('L&S ANIMATION') == 'K APPROVED'
@@ -55,6 +83,53 @@ class RevisionsWorkingCopies(RevisionsWorkingCopiesChoiceValue):
         )
 
 
+class FileRevisionsWorkingCopies(FileRevisionWorkingCopyNameChoiceValue):
+
+    def choices(self):
+        user = self.root().project().get_user()
+        revisions = None
+
+        if user.preferences.create_working_copies.get() == True:
+            if self.get_file() is None:
+                return []
+            
+            revisions = self.get_file().get_revision_names(
+                sync_status='Available',
+            )
+
+            for revision in revisions:
+                if revision == self.root().project().get_user_name():
+                    revisions.remove(revision)
+
+        else:
+            if self.get_file() is None:
+                return []
+            
+            revisions = self.get_file().get_revision_names(
+                sync_status='Available',
+                published_only=True
+            )
+
+        if user.all_working_copy.get() == False:
+            head = self.get_file().get_head_revision().name()
+            last_revisions = []
+            for revision in revisions:
+                if self.get_file().get_revision(revision).is_working_copy():
+                    last_revisions.append(revision)
+                    continue
+                if revision == head:
+                    last_revisions.append(revision)
+            return last_revisions
+        
+        return revisions
+
+
+class FileRefRevisionNameChoiceValue(FileRevisionsWorkingCopies):
+
+    def get_file(self):
+        return self.action.source_file.get()
+
+
 class CreateWorkingCopyFromRevision(BaseCreateWorkingCopyFromRevision):
 
     _file = flow.Parent(4)
@@ -156,6 +231,13 @@ class CreateWorkingCopyAction(BaseCreateWorkingCopyAction):
             shutil.copytree(path_on_site, path_in_workspace)
 
 
+class CreateWorkingCopyFromFile(BaseCreateWorkingCopyFromFile):
+
+    source_revision_name = flow.Param(None, FileRefRevisionNameChoiceValue).ui(
+        label="Source revision"
+    )
+
+
 class KitsuTaskNames(flow.values.SessionValue):
 
     DEFAULT_EDITOR = 'choice'
