@@ -511,7 +511,11 @@ class FilesMap(flow.Map):
         return ["Name", "Target", "Revision"]
 
     def _configure_child(self, child):
+        child.file_name.set('')
         child.file_comment.set('')
+        child.file_path.set('')
+        child.file_target.set('')
+        child.rev_version.set('v001')
 
     def _fill_row_cells(self, row, item):
         row["Name"] = item.file_name.get()
@@ -572,6 +576,8 @@ class ShotsMap(flow.Map):
 
     def _configure_child(self, child):
         child.shot_name.set(child.name())
+        child.new_shot.set(False)
+        child.shot_status.set('')
 
     def _fill_row_cells(self, row, item):
         row["Name"] = item.shot_name.get()
@@ -1001,9 +1007,18 @@ class ImportFiles(flow.Action):
                 
                 #region no valid files
                 if shot_files == []:
+                    find_entry = False
                     for s in incorrect['shots']:
                         if s['shot'] == dir_name:
+                            find_entry = True
                             s['error'] = 'no_valid_files'
+                            break
+                    if find_entry == False:
+                        incorrect['shots'].append({
+                            'shot': dir_name,
+                            'files': [],
+                            'error': 'no_valid_files'
+                        })
                     continue
                 #endregion
 
@@ -1059,9 +1074,18 @@ class ImportFiles(flow.Action):
                 else:
                     if shot_files != []:
                         print('SHOT NOT OKAY!')
+                        find_entry = False
                         for s in incorrect['shots']:
                             if s['shot'] == dir_name:
+                                find_entry = True
                                 s['error'] = 'not_all_files'
+                                break
+                        if find_entry == False:
+                            incorrect['shots'].append({
+                                'shot': dir_name,
+                                'files': [],
+                                'error': 'not_all_files'
+                            })
 
                 #endregion
 
@@ -1193,7 +1217,7 @@ class ImportFiles(flow.Action):
                         
                         print('ImportFiles :: {shot} - Importing {name} ({version})'.format(shot=s, name=target, version=revision_name))
                         shutil.copy2(f.file_path.get(), revision_path)
-                        self._upload_revision(r)
+                        # self._upload_revision(r)
 
                         #Delete file in files_map
                         shot_data.files_map.remove(f.name())
@@ -1219,7 +1243,7 @@ class ImportFiles(flow.Action):
                         
                         print('ImportFiles :: {shot} - Importing {name} ({version})'.format(shot=s, name=target, version=revision_name))
                         shutil.copytree(f.file_path.get(), revision_path)
-                        self._upload_revision(r)
+                        # self._upload_revision(r)
 
                         #Delete file in files_map
                         shot_data.files_map.remove(f.name())
